export var OperatorType;
(function (OperatorType) {
    /** value is empty */
    OperatorType["empty"] = "";
    /**
     * Custom filter operator, this operator will not do anything unless the developer (you) has an implementation associated with the usage of this custom operator.
     * In other words, without any implementation (typically a backend service) this operator does nothing by itself and only exists to provide a way for developers to customize their backend service filtering.
     */
    OperatorType["custom"] = "Custom";
    /** value contains in X (search for substring in the string) */
    OperatorType["contains"] = "Contains";
    /** value is NOT contained in X (inversed of "Contains") */
    OperatorType["notContains"] = "Not_Contains";
    /** value less than X */
    OperatorType["lessThan"] = "LT";
    /** value less than or equal to X */
    OperatorType["lessThanOrEqual"] = "LE";
    /** value greater than X */
    OperatorType["greaterThan"] = "GT";
    /** value great than or equal to X */
    OperatorType["greaterThanOrEqual"] = "GE";
    /** value is NOT equal to X */
    OperatorType["notEqual"] = "NE";
    /** value equal to X */
    OperatorType["equal"] = "EQ";
    /** String ends with value */
    OperatorType["endsWith"] = "EndsWith";
    /**
     * Search in an inclusive range of values that is greater or equal to search value X and is smaller or equal to value Y
     * For example the search term of "5..10" will return any values that are greater or equal to 5 and smaller or equal to 10 (the values 5 and 10 are included)
     */
    OperatorType["rangeInclusive"] = "RangeInclusive";
    /**
     * Search in an exclusive range of values that is greater then search value X and is smaller then value Y
     * For example the search term of "5..10" will return any values that is greater then 5 and smaller then 10 (the values 5 and 10 are NOT to be included)
     */
    OperatorType["rangeExclusive"] = "RangeExclusive";
    /** String starts with value */
    OperatorType["startsWith"] = "StartsWith";
    /** Combo Starts With A + Ends With Z */
    OperatorType["startsWithEndsWith"] = "StartsWithEndsWith";
    /** Find an equal match inside a collection */
    OperatorType["in"] = "IN";
    /** Find a value that is NOT an equal match inside a collection (inversed operator of "IN") */
    OperatorType["notIn"] = "NOT_IN";
    /**
     * Find a substring contained inside a collection, note that the input must be a formatted CSV string input.
     * For example, this condition would return `true` with `"IN_CONTAINS"`:: value='Task2' (or 'Task2,Task3'), collection=['Task2','Task3','Task4]
     * However, this would have returned `false` with "IN" because 'Task2' does not equal to the entire collection 'Task2,Task3,Task4'.
     */
    OperatorType["inContains"] = "IN_CONTAINS";
    /** Find a substring that is NOT contained inside a collection (inversed operator of "IN_CONTAINS") */
    OperatorType["notInContains"] = "NOT_IN_CONTAINS";
    /** Find a value from within a collection inside another collection */
    OperatorType["inCollection"] = "IN_COLLECTION";
    /** Find a value that is NOT within a collection inside another collection (inversed operator of "IN_COLLECTION") */
    OperatorType["notInCollection"] = "NOT_IN_COLLECTION";
})(OperatorType || (OperatorType = {}));
//# sourceMappingURL=operatorType.enum.js.map